#Copyright (c) 2015 3D Control Systems LTD

# Author: Oleg Panasevych <panasevychol@gmail.com>

import os
import sys
import logging
import subprocess
import cloud_sync
import signal

import config
import platforms


class CloudSyncController:

    CLOUD_SYNC_MODULE = 'cloud_sync.py'

    def __init__(self):
        self.logger = logging.getLogger(__name__)
        self.cloud_sync_process = None
        if config.get_settings()['cloud_sync']['enabled'] and self.CLOUD_SYNC_MODULE:
            self.start_cloud_sync_process()

    def start_cloud_sync_process(self):
        self.logger.info('Launching CloudSync subprocess')
        cs_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), self.CLOUD_SYNC_MODULE)
        try:
            self.cloud_sync_process = subprocess.Popen([sys.executable, cs_path], close_fds=True)
        except Exception as e:
            self.logger.warning('Could not launch CloudSync due to error:\n' + str(e))

    def stop_cloud_sync_process(self):
        if self.cloud_sync_process:
            self.logger.info('Stopping CloudSync process..')
            self.cloud_sync_process.terminate()
            while True:
                try:
                    if self.cloud_sync_process.poll() != None:
                        break
                except OSError:
                    break
            self.logger.info('...CloudSync is stopped')
            self.cloud_sync_process = None

    def open_cloud_sync_folder(self):
        path = os.path.abspath(cloud_sync.Cloudsync.PATH)
        if sys.platform.startswith('darwin'):
            subprocess.Popen(['open', path])
        elif sys.platform.startswith('linux'):
            subprocess.Popen(['xdg-open', path])
        elif sys.platform.startswith('win32'):
            subprocess.Popen(['explorer', path])